
# Optimization Techniques

**Optimization Techniques** is a Python package that includes eight powerful algorithms for optimization tasks, including Genetic Algorithm, Particle Swarm Optimization, Simulated Annealing, Ant Colony Optimization, Gray Wolf Optimization, and more. This package is designed to help users experiment with different optimization approaches for a wide variety of continuous and discrete problems.

## Table of Contents

1. [Installation](#installation)
2. [Usage](#usage)
3. [Available Programs Variables](#available-algorithms)
4. [Contributing](#contributing)
5. [License](#license)

---

## Installation

You can install the `optimization_techniques` package directly from PyPI:

```bash
pip install dharun
```

## Usage

Once installed, you can import the package and start using any of the algorithms. Here’s a general example of how to import and use a variable from this package:

```python
from programs import continuous_optimization

# Define your objective function
print(continuous_optimization.continuous_optimization)
print(continuous_optimization.binary_optimization)

#It will print the full code
```

## Available Programs Variables

The following algorithms are available in the `programs` package:

1. `continuous_optimization`
   - continuous_optimization

2. `binary_optimization`
    - binary_optimization

3. `simulated_annealing`
   - simulated_annealing

4. `ant_colony_algorithm`
   - ant_colony_algorithm

5. `particle_swarn_optimization`
   - particle_swarn_optimization

6. `gray_wolf_optimization`
   - gray_wolf_optimization

7. `tabu_search`
   - tabu_search

8. `shuffuled_frog_optimization`
   - shuffuled_frog_optimization

9. `tsp`
   - tsp


## Contributing

We welcome contributions! If you’d like to contribute, please fork the repository, make your changes, and submit a pull request. 

## License

This project is licensed under the MIT License. See the `LICENSE` file for details.

